pyCARLANeT
===============
## Introduction
pyCARLANeT is the carla side of the open source library CARLANeT for the co-simulation between CARLA and OMNeT++.

## Requirements
In accordance to [CARLA documentation](https://carla.readthedocs.io/en/latest/start_quickstart/), pyCARLANeT is compatible with Python version 3.8.x. and with pip > 22.x.
To upgrade pip you can use:
```shell
pip install --upgrade pip==22.*
```

## Installation
You can install **pyCARLANeT** directly from [pypi](https://pypi.org/project/pycarlanet/). 
```shell
pip install pycarlanet
```

## Usage
To learn how to utilize this library, refer to the documentation or the [sample code provided](sample/template_car_pedestrian.py). 
